# KGCL: Knowledge Graph Change Language

KGCL is a standard datamodel for representing changes in ontologies and knowledge graphs.

This repository houses:

- The KGCL schema/standard
- The Python implementation of the standard (LinkML model, LARK grammar)

## Documentation

[Read more here.](https://incatools.github.io/kgcl/)

